@@ -24,9 +24,10 @@ def changename(path):
         return path
     else:
         return '/cygdrive/'+path.replace('\\','/').replace(':','')
-
-def mktorrent(filepath,torrentname,tracker="https://announce.leaguehd.com/announce.php"):
-
+def mktorrent_win(filepath,torrentname,tracker="https://announce.leaguehd.com/announce.php"):
+    cwd=os.getcwd()
+    newcwd=os.path.dirname(filepath)
+    os.chdir(newcwd)
     if os.path.isdir(filepath):
         logger.info('检测到路径制种，将先删除掉路径里面所有种子文件(torrent后缀)以及隐藏文件（.开头的文件）...')
         deletetorrent(filepath) 
@@ -38,10 +39,28 @@ def mktorrent(filepath,torrentname,tracker="https://announce.leaguehd.com/announ
         except Exception as r:
             logger.error('删除种子发生错误: %s' %(r))
     logger.info('正在制作种子:'+filepath)
+    order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+os.path.basename(filepath)+'\"'+''
+    logger.info(order)
+    os.system(order)
+    logger.info('已完成制作种子'+torrentname)
+    os.chdir(cwd)
+
+def mktorrent(filepath,torrentname,tracker="https://announce.leaguehd.com/announce.php"):
     if 'win' in sys.platform:
-        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+filepath+'\"'+''
-    else:
-        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+filepath+'\"'+' > /dev/null'
+        mktorrent_win(filepath,torrentname,tracker)
+        return 
+    if os.path.isdir(filepath):
+        logger.info('检测到路径制种，将先删除掉路径里面所有种子文件(torrent后缀)以及隐藏文件（.开头的文件）...')
+        deletetorrent(filepath) 
+    logger.info('即将开始制作种子...')
+    if os.path.exists(torrentname):
+        logger.info('已存在种子文件，正在删除'+torrentname)
+        try:
+            os.remove(torrentname)
+        except Exception as r:
+            logger.error('删除种子发生错误: %s' %(r))
+    logger.info('正在制作种子:'+filepath)
+    order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+torrentname+ '\" \"'+filepath+'\"'+' > /dev/null'
     #logger.info(order)
     os.system(order)
     logger.info('已完成制作种子'+torrentname)
