@@ -9,7 +9,11 @@ from bs4 import BeautifulSoup
 def recordupload(torrent_file,file1,String_url,downloadurl):
     logger.info('正在记录发布的资源到'+torrent_file)
     if not os.path.exists(torrent_file):
-        f = open(torrent_file,'w+',encoding='utf-8-sig')
+        if 'win' in sys.platform:
+            f = open(torrent_file,'w+',encoding='utf-8')
+        else:
+            f = open(torrent_file,'w+',encoding='utf-8-sig')
+
         f.write('中文名,集数,发布日期,资源链接,资源下载链接\n0\n')
         f.close()
 
@@ -45,8 +49,10 @@ def recordupload(torrent_file,file1,String_url,downloadurl):
     logger.debug(newstr)
 
     filestr=filestr+newstr+str(num+1)+'\n'
-    
-    f = open(torrent_file,'w+',encoding='utf-8-sig')
+    if 'win' in sys.platform:
+        f = open(torrent_file,'w+',encoding='utf-8')
+    else:
+        f = open(torrent_file,'w+',encoding='utf-8-sig')
     f.write(filestr)
     f.close()
     logger.info('记录完毕')
